function [a,b,e2,finv]=ref_ell(type)
% REF_ELL  Computes reference ellispoid parameters.
%   Reference: Department of Defence World Geodetic
%   System 1984, DMA TR 8350.2, 1987.
%   TOPEX Reference: <http://topex-www.jpl.nasa.gov/aviso/text/general/news/hdbk311.htm#CH3.3>
% Version: 1 Jun 04
% Useage:  [a,b,e2,finv]=ref_ell(type)
% Input:   type - reference ellipsoid type (char)
%                 CLK66 = Clarke 1866
%                 GRS67 = Geodetic Reference System 1967
%                 GRS80 = Geodetic Reference System 1980
%                 WGS72 = World Geodetic System 1972
%                 WGS84 = World Geodetic System 1984
%                 ATS77 = Quasi-earth centred ellipsoid for ATS77
%                 NAD27 = North American Datum 1927 (=CLK66)
%                 NAD83 = North American Datum 1927 (=GRS80)
%                 INTER = International
%                 KRASS = Krassovsky (USSR)
%                 MAIRY = Modified Airy (Ireland 1965/1975)
%                 TOPEX = TOPEX/POSEIDON ellipsoid
% Output:  a    - major semi-axis (m)
%          b    - minor semi-axis (m)
%          e2   - eccentricity squared
%          finv - inverse of flattening

% Copyright (c) 2011, Michael R. Craymer
% All rights reserved.
% Email: mike@craymer.com

% Modified by Mohammad Ali Goudarzi
% Modification date: August 28, 2013
% Email: ma_goudarzi@yahoo.com

type=upper(type);
switch type
    case 'WGS84'
      a=6378137.0;
      finv=298.257223563;
      
    case {'CLK66', 'NAD27'}
      a=6378206.4;
      finv=294.9786982;
      
    case 'GRS67'
      a=6378160.0;
      finv=298.247167427;
      
    case {'GRS80', 'NAD83'}
      a=6378137.0;
      finv=298.257222101;
      
    case 'WGS72'
      a=6378135.0;
      finv=298.26;
      
    case 'ATS77'
      a=6378135.0;
      finv=298.257;
      
    case 'KRASS'
      a=6378245.0;
      finv=298.3;
      
    case 'INTER'
      a=6378388.0;
      finv=297.0;
      
    case 'MAIRY'
      a=6377340.189;
      finv=299.3249646;
      
    case 'TOPEX'
      a=6378136.3;
      finv=298.257;
end

f=1/finv;
b=a*(1-f);
e2=1-(1-f)^2;

return;

